@@ -52,8 +52,8 @@ class LetsEncrypt:
         client = boto3.client('route53')
 
         for hostname in subject_alternative_names:
-            hosted_zone = os.environ['HOSTED_ZONE_ID']
             try:
+                hosted_zone = os.environ['HOSTED_ZONE_ID']
                 response = client.list_resource_record_sets(
                     HostedZoneId=hosted_zone,
                     StartRecordName='_acme-challenge.{hostname}'.format(
@@ -68,27 +68,25 @@ class LetsEncrypt:
                     sys.exit(1)
 
             except Exception:
-                raise Exception(
-                    'Invalid FQDN: {hostname}'.format(hostname=hostname))
+                raise KeyError('HOSTED_ZONE_ID Invalid')
 
     def _register_lets_encrypt_account(self) -> None:
         prefix = os.environ['PREFIX']
         home = os.environ['HOME']
-        region = os.environ['AWS_REGION']
         try:
             source_dir = "acme-v02.api.letsencrypt.org"
             acme_account = f"{home}/.acme.sh/ca/{source_dir}"
             if not os.path.exists(acme_account):
                 os.makedirs(acme_account)
 
-            account_json = get_secret(f'{prefix}/otter/account.json', region)
+            account_json = get_secret(f'{prefix}/otter/account.json', element=None, region=self.region)
             with open('account.json', 'w') as outfile:
                 outfile.write(account_json)
-            account_key = get_secret(f'{prefix}/otter/account.key', region)
+            account_key = get_secret(f'{prefix}/otter/account.key', region=self.region)
             with open('account.key', 'w') as outfile:
                 outfile.write(account_key)
 
-            ca_conf = get_secret(f'{prefix}/otter/ca.conf', region)
+            ca_conf = get_secret(f'{prefix}/otter/ca.conf', region=self.region)
             with open('ca.conf', 'w') as outfile:
                 outfile.write(ca_conf)
 
@@ -99,8 +97,7 @@ class LetsEncrypt:
             shutil.move(
                 "ca.conf", "{acme_account}/ca.conf".format(acme_account=acme_account))
         except Exception:
-            message = 'ACME Account Binding Error on `{hostname}`.'.format(
-                hostname=self.hostname)
+            message = 'ACME Account Binding Error.'
             LOGGER.error(message)
             sys.exit(1)
 
