@@ -40,17 +40,8 @@ def get_secret(path, element=None, region: str = 'us-east-1') -> str:
         get_secret_value_response = client.get_secret_value(
             SecretId=path
         )
-    except ClientError as e:
-        if e.response['Error']['Code'] == 'DecryptionFailureException':
-            raise e
-        elif e.response['Error']['Code'] == 'InternalServiceErrorException':
-            raise e
-        elif e.response['Error']['Code'] == 'InvalidParameterException':
-            raise e
-        elif e.response['Error']['Code'] == 'InvalidRequestException':
-            raise e
-        elif e.response['Error']['Code'] == 'ResourceNotFoundException':
-            raise e
+    except ClientError as error:
+        raise error
     else:
         if 'SecretString' in get_secret_value_response:
             secret = get_secret_value_response['SecretString']
@@ -69,7 +60,8 @@ def query_subject_alternative_names(hostname, table) -> List[str]:
     if response['ResponseMetadata']['HTTPStatusCode'] == 200:
         return response['Items'][0]['subject_alternative_name']
     else:
-        return [hostname]
+        LOGGER.error('DynamoDB Returned Invalid HTTPStatusCode')
+        sys.exit(1)
 
 
 def update_certificate_expiration(hostname, table, certificate_expiration) -> None:
